@@ -322,7 +322,7 @@ def dtc_decrypt(code):
     return res
 
 def hex_to_bitstring(str):
-    print "obd_sensors.hex_to_bistring(str): " + str
+    #print "obd_sensors.hex_to_bistring(str): " + str
     bitstring = ""
     for i in str:
         # silly type safety, we don't want to eval random stuff
